migrate

Function migrate 

pub async fn migrate(
    attributes: Vec<impl AsAttributes>,
    replace: bool,
) -> Result<()>
Helper to migrate your secrets from the host Secret Service to the sandboxed file backend.

If the migration is successful, the items are removed from the host Secret Service.